@@ -91,6 +91,8 @@
 #'   }
 #'   standardize(slopes)
 #'
+#'   \dontrun{
+#'   # TODO: fails with latest emmeans (1.8.0)
 #'   if (require("mgcv") && require("see")) {
 #'     model <- mgcv::gam(Sepal.Width ~ s(Petal.Length), data = iris)
 #'     slopes <- estimate_slopes(model, at = "Petal.Length", length = 50)
@@ -104,7 +106,7 @@
 #'     )
 #'     summary(slopes)
 #'     plot(slopes)
-#'   }
+#'   }}
 #' }
 #' @return A data.frame of class `estimate_slopes`.
 #' @export
@@ -113,7 +115,6 @@ estimate_slopes <- function(model,
                             at = NULL,
                             ci = 0.95,
                             ...) {
-
   # Sanitize arguments
   estimated <- get_emtrends(model, trend, at, ...)
   info <- attributes(estimated)
@@ -176,7 +177,7 @@ summary.estimate_slopes <- function(object, ...) {
     # Create vizmatrix of grouping variables
     groups <- as.data.frame(insight::get_datagrid(data[vars], factors = "all", numerics = "all"))
     # Summarize all of the chunks
-    for (i in 1:nrow(groups)) {
+    for (i in seq_len(nrow(groups))) {
       g <- datawizard::data_match(data, groups[i, , drop = FALSE])
       out <- rbind(out, .estimate_slopes_summarize(g, trend = trend))
     }
@@ -195,7 +196,6 @@ summary.estimate_slopes <- function(object, ...) {
 
 # Utilities ---------------------------------------------------------------
 .estimate_slopes_summarize <- function(data, trend, ...) {
-
   # Find beginnings and ends -----------------------
   # First row - starting point
   signs <- sign(data[[datawizard::data_find(data, c("Coefficient", "Median", "Mean", "MAP_Estimate"), verbose = FALSE)]])
@@ -205,7 +205,7 @@ summary.estimate_slopes <- function(object, ...) {
   ends <- nrow(data)
   # Iterate through all rows to find blocks
   for (i in 2:nrow(data)) {
-    if ((data$Confidence[i] != sig) | ((signs[i] != sign) & data$Confidence[i] == "Uncertain")) {
+    if ((data$Confidence[i] != sig) || ((signs[i] != sign) && data$Confidence[i] == "Uncertain")) {
       sign <- signs[i]
       sig <- data$Confidence[i]
       starts <- c(starts, i)
@@ -216,7 +216,7 @@ summary.estimate_slopes <- function(object, ...) {
 
   # Summarize these groups -----------------------
   out <- data.frame()
-  for (g in 1:length(starts)) {
+  for (g in seq_len(length(starts))) {
     dat <- data[starts[g]:ends[g], ]
     dat <- as.data.frame(insight::get_datagrid(dat, at = NULL, factors = "mode"))
     dat <- cbind(data.frame("Start" = data[starts[g], trend], "End" = data[ends[g], trend]), dat)
