@@ -1,5 +1,4 @@
 if (require("testthat") && require("modelbased") && require("glmmTMB") && require("emmeans")) {
-
   # skip_on_cran()
 
   data <- glmmTMB::Salamanders
@@ -47,8 +46,8 @@ if (require("testthat") && require("modelbased") && require("glmmTMB") && requir
 
 
   test_that("estimate_response - glmmTMB", {
-    estim <- estimate_response(model2)
-    expect_equal(dim(estim), c(nrow(data), 9))
+    estim <- estimate_expectation(model2)
+    expect_equal(dim(estim), c(nrow(data), 8))
   })
 
   test_that("estimate_link - glmmTMB", {
@@ -57,7 +56,7 @@ if (require("testthat") && require("modelbased") && require("glmmTMB") && requir
   })
 
   test_that("estimate_response - glmmTMB", {
-    estim <- estimate_response(model2)
-    expect_equal(dim(estim), c(644, 9))
+    estim <- estimate_expectation(model2)
+    expect_equal(dim(estim), c(644, 8))
   })
 }
